@@ -13,13 +13,26 @@ import { normalizePath, walk } from './utils/index.js';
 
 const dirname = fileURLToPath(new URL('.', import.meta.url));
 
+export const dataFolders = [
+  'api',
+  'browsers',
+  'css',
+  'html',
+  'http',
+  'javascript',
+  'mathml',
+  'svg',
+  'webassembly',
+  'webdriver',
+  'webextensions',
+];
+
 /**
  * Recursively load one or more directories passed as arguments.
- *
- * @param {string[]} dirs The directories to load
- * @returns {object} All of the browser compatibility data
+ * @param dirs The directories to load
+ * @returns All of the browser compatibility data
  */
-const load = async (...dirs: string[]) => {
+const load = async (...dirs: string[]): Promise<CompatData> => {
   const result = {};
 
   for (const dir of dirs) {
@@ -41,25 +54,16 @@ const load = async (...dirs: string[]) => {
         }
 
         extend(result, contents);
+        /* c8 ignore start */
       } catch (e) {
         // Skip invalid JSON. Tests will flag the problem separately.
         continue;
       }
+      /* c8 ignore stop */
     }
   }
 
-  return result;
+  return result as CompatData;
 };
 
-export default (await load(
-  'api',
-  'browsers',
-  'css',
-  'html',
-  'http',
-  'javascript',
-  'mathml',
-  'svg',
-  'webdriver',
-  'webextensions',
-)) as CompatData;
+export default await load(...dataFolders);
