@@ -8,7 +8,7 @@ import { Identifier } from '../../types/types.js';
 import { removeWebViewFlags } from './002-remove-webview-flags.js';
 
 /**
- * @constant {{input: Identifier, output: Identifier}[]} Objects of each test, with input and expected output
+ * Objects of each test, with input and expected output
  */
 const tests: { input: Identifier; output: Identifier }[] = [
   {
@@ -127,7 +127,7 @@ describe('migration scripts', () => {
     for (const test of tests) {
       const expected = test.output;
       const output = JSON.parse(JSON.stringify(test.input), removeWebViewFlags);
-      assert.deepStrictEqual(output, expected);
+      assert.deepEqual(output, expected);
     }
   });
 });
