@@ -8,17 +8,16 @@ import { fileURLToPath } from 'node:url';
 import esMain from 'es-main';
 
 import { CompatStatement, SimpleSupportStatement } from '../../types/types.js';
-import { IS_WINDOWS } from '../../test/utils.js';
+import { IS_WINDOWS } from '../../lint/utils.js';
 
 const dirname = fileURLToPath(new URL('.', import.meta.url));
 
 /**
  * Check to see if the key is __compat and modify the value to remove
  * flags from WebView Android.
- *
- * @param {string} key The key in the object
- * @param {CompatStatement} value The value of the key
- * @returns {CompatStatement} The new value with WebView flags removed
+ * @param key The key in the object
+ * @param value The value of the key
+ * @returns The new value with WebView flags removed
  */
 export const removeWebViewFlags = (
   key: string,
@@ -28,9 +27,9 @@ export const removeWebViewFlags = (
     if (value.support.webview_android !== undefined) {
       if (Array.isArray(value.support.webview_android)) {
         const result: SimpleSupportStatement[] = [];
-        for (let i = 0; i < value.support.webview_android.length; i++) {
-          if (value.support.webview_android[i].flags === undefined) {
-            result.push(value.support.webview_android[i]);
+        for (const support of value.support.webview_android) {
+          if (support.flags === undefined) {
+            result.push(support);
           }
         }
 
@@ -53,8 +52,7 @@ export const removeWebViewFlags = (
  * Perform removal of flags within WebView data within all the data in a
  * specified file. The function will then automatically write any needed
  * changes back into the file.
- *
- * @param {string} filename The filename to perform migration upon
+ * @param filename The filename to perform migration upon
  */
 export const fixWebViewFlags = (filename: string): void => {
   let actual = fs.readFileSync(filename, 'utf-8').trim();
@@ -78,8 +76,7 @@ export const fixWebViewFlags = (filename: string): void => {
 /**
  * Recursively load one or more files and/or directories passed as arguments
  * and perform removal of flags from WebView support data.
- *
- * @param {string[]} files The files to load and perform migration upon
+ * @param files The files to load and perform migration upon
  */
 const load = (...files: string[]): void => {
   for (let file of files) {
@@ -120,6 +117,7 @@ if (esMain(import.meta)) {
       'javascript',
       'mathml',
       'test',
+      'webassembly',
       'webdriver',
       'webextensions',
     );
