@@ -6,23 +6,25 @@ import yargs from 'yargs';
 import { hideBin } from 'yargs/helpers';
 
 import { BrowserName, Identifier } from '../types/types.js';
-import bcd from '../index.js';
+import { InternalSupportStatement } from '../types/index.js';
+import bcd, { dataFolders } from '../index.js';
 
 /**
  * Traverse all of the features within a specified object and find all features that have one of the specified values
- *
- * @param {Identifier} obj The compat data to traverse through
- * @param {BrowserName[]} browsers The browsers to test for
- * @param {string[]} values The values to test for
- * @param {number} depth The depth to traverse
- * @param {string} identifier The identifier of the current object
+ * @param obj The compat data to traverse through
+ * @param browsers The browsers to test for
+ * @param values The values to test for
+ * @param depth The depth to traverse
+ * @param tag The tag to filter results with
+ * @param identifier The identifier of the current object
  * @yields {string} The feature identifier
  */
-function* iterateFeatures(
-  obj,
+export function* iterateFeatures(
+  obj: Identifier,
   browsers: BrowserName[],
   values: string[],
   depth: number,
+  tag: string,
   identifier: string,
 ): IterableIterator<string> {
   depth--;
@@ -30,45 +32,57 @@ function* iterateFeatures(
     for (const i in obj) {
       if (!!obj[i] && typeof obj[i] == 'object' && i !== '__compat') {
         if (obj[i].__compat) {
-          const comp = obj[i].__compat.support;
-          for (const browser of browsers) {
-            let browserData = comp[browser];
-
-            if (!browserData) {
-              if (values.length == 0 || values.includes('null')) {
-                yield `${identifier}${i}`;
-              }
+          if (tag) {
+            const tags = obj[i].__compat?.tags;
+            if (tags && tags.includes(tag)) {
+              yield `${identifier}${i}`;
+            }
+          } else {
+            const comp = obj[i].__compat?.support;
+            if (!comp) {
               continue;
             }
-            if (!Array.isArray(browserData)) {
-              browserData = [browserData];
-            }
+            for (const browser of browsers) {
+              let browserData = comp[browser];
 
-            for (const range in browserData) {
-              if (browserData[range] === 'mirror') {
-                if (values.includes('mirror')) {
-                  yield `${identifier}${i}`;
-                }
-              } else if (values.includes('nonmirror')) {
-                // If checking for non-mirrored data and it's not mirrored
-                yield `${identifier}${i}`;
-              } else if (browserData[range] === undefined) {
+              if (!browserData) {
                 if (values.length == 0 || values.includes('null')) {
                   yield `${identifier}${i}`;
                 }
-              } else if (
-                values.length == 0 ||
-                values.includes(String(browserData[range].version_added)) ||
-                values.includes(String(browserData[range].version_removed))
-              ) {
-                let f = `${identifier}${i}`;
-                if (browserData[range].prefix) {
-                  f += ` (${browserData[range].prefix} prefix)`;
+                continue;
+              }
+              if (!Array.isArray(browserData)) {
+                browserData = [browserData];
+              }
+
+              for (const range in browserData) {
+                if (
+                  (browserData[range] as InternalSupportStatement) === 'mirror'
+                ) {
+                  if (values.includes('mirror')) {
+                    yield `${identifier}${i}`;
+                  }
+                } else if (values.includes('nonmirror')) {
+                  // If checking for non-mirrored data and it's not mirrored
+                  yield `${identifier}${i}`;
+                } else if (browserData[range] === undefined) {
+                  if (values.length == 0 || values.includes('null')) {
+                    yield `${identifier}${i}`;
+                  }
+                } else if (
+                  values.length == 0 ||
+                  values.includes(String(browserData[range].version_added)) ||
+                  values.includes(String(browserData[range].version_removed))
+                ) {
+                  let f = `${identifier}${i}`;
+                  if (browserData[range].prefix) {
+                    f += ` (${browserData[range].prefix} prefix)`;
+                  }
+                  if (browserData[range].alternative_name) {
+                    f += ` (as ${browserData[range].alternative_name})`;
+                  }
+                  yield f;
                 }
-                if (browserData[range].alternative_name) {
-                  f += ` (as ${browserData[range].alternative_name})`;
-                }
-                yield f;
               }
             }
           }
@@ -78,6 +92,7 @@ function* iterateFeatures(
           browsers,
           values,
           depth,
+          tag,
           identifier + i + '.',
         );
       }
@@ -87,23 +102,24 @@ function* iterateFeatures(
 
 /**
  * Traverse all of the features within a specified object and find all features that have one of the specified values
- *
- * @param {Identifier} obj The compat data to traverse through
- * @param {string[]} browsers The browsers to traverse for
- * @param {string[]} values The version values to traverse for
- * @param {number} depth The depth to traverse
- * @param {string} identifier The identifier of the current object
- * @returns {string[]} An array of the features
+ * @param obj The compat data to traverse through
+ * @param browsers The browsers to traverse for
+ * @param values The version values to traverse for
+ * @param depth The depth to traverse
+ * @param tag The tag to filter results with
+ * @param identifier The identifier of the current object
+ * @returns An array of the features
  */
 const traverseFeatures = (
-  obj,
+  obj: Identifier,
   browsers: BrowserName[],
   values: string[],
   depth: number,
+  tag: string,
   identifier: string,
 ): string[] => {
   const features = Array.from(
-    iterateFeatures(obj, browsers, values, depth, identifier),
+    iterateFeatures(obj, browsers, values, depth, tag, identifier),
   );
 
   return features.filter((item, pos) => features.indexOf(item) == pos);
@@ -111,27 +127,19 @@ const traverseFeatures = (
 
 /**
  * Traverse the features within BCD
- *
- * @param {string[]} folders The folders to traverse
- * @param {BrowserName[]} browsers The browsers to traverse for
- * @param {string[]} values The version values to traverse for
- * @param {number} depth The depth to traverse
- * @returns {string[]} The list of features
+ * @param folders The folders to traverse
+ * @param browsers The browsers to traverse for
+ * @param values The version values to traverse for
+ * @param depth The depth to traverse
+ * @param tag The tag to filter results with
+ * @returns The list of features
  */
 const main = (
-  folders = [
-    'api',
-    'css',
-    'html',
-    'http',
-    'svg',
-    'javascript',
-    'mathml',
-    'webdriver',
-  ],
+  folders = dataFolders.concat('webextensions'),
   browsers: BrowserName[] = Object.keys(bcd.browsers) as BrowserName[],
   values = ['null', 'true'],
   depth = 100,
+  tag = '',
 ): string[] => {
   const features: string[] = [];
 
@@ -142,6 +150,7 @@ const main = (
         browsers,
         values,
         depth,
+        tag,
         folders[folder] + '.',
       ),
     );
@@ -178,6 +187,13 @@ if (esMain(import.meta)) {
           nargs: 1,
           default: [],
         })
+        .option('tag', {
+          alias: 't',
+          describe: 'Filter by tag value.',
+          type: 'string',
+          nargs: 1,
+          default: '',
+        })
         .option('non-real', {
           alias: 'n',
           describe:
@@ -208,13 +224,23 @@ if (esMain(import.meta)) {
         .example(
           'npm run traverse -- -b samsunginternet_android -f mirror',
           'Find all features in Samsung Internet that mirror data from Chrome Android',
+        )
+        .example(
+          'npm run traverse -- -t web-features:idle-detection',
+          'Find all features tagged with web-features:idle-detection.',
         );
     },
   );
 
   const filter = [...argv.filter, ...(argv.nonReal ? ['true', 'null'] : [])];
 
-  const features = main(argv.folder, argv.browser, filter, argv.depth);
+  const features = main(
+    argv.folder,
+    argv.browser,
+    filter,
+    argv.depth,
+    argv.tag,
+  );
   console.log(features.join('\n'));
   console.log(features.length);
 }
