@@ -14,32 +14,31 @@ import bcd from '../index.js';
 import { isBrowser, descendantKeys, joinPath } from './walkingUtils.js';
 import query from './query.js';
 
-type BrowserReleaseWalkOutput = {
+interface BrowserReleaseWalkOutput {
   path: string;
   data: DataType;
   browser: BrowserStatement;
   browserRelease: ReleaseStatement;
-};
+}
 
-type LowLevelWalkOutput = {
+interface LowLevelWalkOutput {
   path: string;
   data: DataType;
   browser?: BrowserStatement;
   compat?: CompatStatement;
   browserRelease?: ReleaseStatement;
-};
+}
 
-type WalkOutput = {
+export interface WalkOutput {
   path: string;
   data: DataType;
   compat: CompatStatement;
-};
+}
 
 /**
  * Walk through the browser releases
- *
- * @param {DataType} data The data to iterate
- * @param {string?} path The current path
+ * @param data The data to iterate
+ * @param path The current path
  * @yields {BrowserReleaseWalkOutput} The release info
  */
 export function* browserReleaseWalk(
@@ -58,10 +57,9 @@ export function* browserReleaseWalk(
 
 /**
  * Walk through the compatibility statements
- *
- * @param {DataType} data The data to iterate
- * @param {string?} path The current path
- * @param {number} depth The maximum depth to iterate
+ * @param data The data to iterate
+ * @param path The current path
+ * @param depth The maximum depth to iterate
  * @yields {LowLevelWalkOutput} The feature info
  */
 export function* lowLevelWalk(
@@ -96,9 +94,8 @@ export function* lowLevelWalk(
 
 /**
  * Walk the data for compat features
- *
- * @param {string|string[]} entryPoints Entry points to iterate
- * @param {DataType} data The data to iterate
+ * @param entryPoints Entry points to iterate
+ * @param data The data to iterate
  * @yields {WalkOutput} The feature info
  */
 export default function* walk(
